==> privileged_residues-0.2.3.tar.gz: privileged_residues-0.2.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'more_itertools',
    # TODO: put package requirements here
]

setup_requirements = [
    'pytest-runner',
    # TODO(weitzner): put setup requirements (distutils extensions, etc.) here
]

test_requirements = [
    'pytest',
    # TODO: put package test requirements here
]

setup(
    name='privileged_residues',
    version='0.2.3',
    description="Privileged Residues contains methods for placing residues on the surface of a target protein that can be added to a RIF.",
    long_description=readme + '\n\n' + history,
    author="Brian D. Weitzner",
    author_email='weitzner@uw.edu',
    url='https://github.com/weitzner/privileged_residues',
    packages=find_packages(include=['privileged_residues']),
    entry_points={
        'console_scripts': [
            'privileged_residues=privileged_residues.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache Software License 2.0",
    zip_safe=False,
    keywords='privileged_residues',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)

==> privileged_residues-0.3.2.tar.gz: privileged_residues-0.3.2/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'more_itertools',
    # TODO: put package requirements here
]

setup_requirements = [
    'pytest-runner',
    # TODO(weitzner): put setup requirements (distutils extensions, etc.) here
]

test_requirements = [
    'pytest',
    # TODO: put package test requirements here
]

setup(
    name='privileged_residues',
    version='0.3.2',
    description="Privileged Residues contains methods for placing residues on the surface of a target protein that can be added to a RIF.",
    long_description=readme + '\n\n' + history,
    author="Brian D. Weitzner",
    author_email='weitzner@uw.edu',
    url='https://github.com/RosettaCommons/privileged_residues',
    packages=find_packages(include=['privileged_residues']),
    entry_points={
        'console_scripts': [
            'privileged_residues=privileged_residues.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache Software License 2.0",
    zip_safe=False,
    keywords='privileged_residues',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)
